(disconnect broker)Closes the connection to the JMS broker
Closes the connection to the JMS broker
(jms-broker config)Creates an event broker uses JMS
Creates an event broker uses JMS
(make-state)Creates a new empty state object that can be passed to a new JmsBroker.
Creates a new empty state object that can be passed to a new JmsBroker.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |